@@ -303,6 +303,8 @@ session_C_OpenSession (SessionInfo *sinfo, GkrPkcs11Message *req,
 	sinfo->pid = pid;
 	sinfo->session = gkr_pk_session_new_for_client (pid);
 	
+	gkr_pk_storage_refresh_all ();
+	
 	return CKR_OK;
 }
 
@@ -421,7 +423,7 @@ session_C_CreateObject (SessionInfo *sinfo, GkrPkcs11Message *req,
                         GkrPkcs11Message *resp)
 {
 	CK_OBJECT_CLASS cls;
-	GkrPkObject *object;
+	GkrPkObject *object = NULL;
 	GArray *attrs = NULL;
 	CK_BBOOL token;
 	CK_RV ret;
@@ -466,7 +468,8 @@ session_C_CreateObject (SessionInfo *sinfo, GkrPkcs11Message *req,
 	ret = CKR_OK;
 	
 done:
-	g_object_unref (object);
+	if (object)
+		g_object_unref (object);
 	gkr_pk_attributes_free (attrs);
 	return ret;
 }
